# statshub Library

This Python library provides functions for various mathematical and statical operations such as calculating factorials, permutations, variations, and combinations.

## Installation

You can install this package via pip:

```bash
pip install statshub
```